// <copyright file="Form1.cs" company="IGProgram">
//      Copyright  Ivica Gjorgjievski 2010 All rights reserved.
//      http://www.igprogram.webs.com
//      igprogram@hotmail.com
// </copyright>

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;
using System.Threading;

using System.Drawing.Imaging;
using System.IO;

namespace IGProgram.VirtualDesktop
{
    /// <summary>
    /// Desktops management form
    /// </summary>
    public partial class Form1 : Form
    {
        // Current desktop name, set in Form_Load
        private string currentDesktop = "";


        public Form1()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Load preview desktop images into PictureBox controls 
        /// </summary>
        private void LoadScreenshots()
        {
            for (int index = 1; index < 5; index++)
            {
                string path = ".\\Desktop" + index.ToString();  // Name of the image

                if (File.Exists(path))  // If file exists
                {
                    // Create memory stream to hold the image for use, otherwise the file will be locked and unusable forther
                    MemoryStream stream = new MemoryStream();
                    Image image = Bitmap.FromFile(path);
                    image.Save(stream, ImageFormat.Jpeg);  // Load image file to memory stream
                    image.Dispose();     // Dispose and unlock the file

                    // Get the PictureBox name and load in it image from memory
                    string pictureBox = "pictureBox" + index.ToString();
                    ((PictureBox)tableLayoutPanel1.Controls[pictureBox]).Image = Bitmap.FromStream(stream);
                }// if

            }// for

        }// LoadScreenshots()


        /// <summary>
        /// Load screenshot from current desktop into associated PictureBox
        /// </summary>
        private void LoadScreenshot()
        {
            switch (currentDesktop)
            {
                case "Default":
                    pictureBox1.Image = Screenshot.CaptureScreen(this);
                    break;
                case "Desktop2":
                    pictureBox2.Image = Screenshot.CaptureScreen(this);
                    break;
                case "Desktop3":
                    pictureBox3.Image = Screenshot.CaptureScreen(this);
                    break;
                case "Desktop4":
                    pictureBox4.Image = Screenshot.CaptureScreen(this);
                    break;
            }// switch

        }


        /// <summary>
        /// Initialize desktop, save current screenshot create new desktop if not exsists and switch to it.
        /// </summary>
        /// <param name="desktopName">Desktop name</param>
        private void DesktopInitialize(string name)
        {
            // Safe current screenshot to image file
            DesktopSave();

            // If desktop not exists create new and initialize processes on in
            if (!Desktops.DesktopExists(name))
            {
                Desktops.DesktopCreate(name);
                Desktops.ProcessCreate(name, Application.ExecutablePath, "start");     // Start VirtualDesktop application
            }

            Desktops.DesktopSwitch(name);     // Switch to desktop

        }// DesktopInitialize


        /// <summary>
        /// Save screenshot from current desktop to image file
        /// </summary>
        private void DesktopSave()
        {
            string path = currentDesktop;
            if (path == "Default") { path = "Desktop1"; }
            path = ".\\" + path;

            Thread.Sleep(300);     // Wait to minimize current window
            Screenshot.SaveScreen(path, ImageFormat.Jpeg, this); // Save file to disk
        }//


        /// <summary>
        /// Delete screenshots for desktops that do not exists.
        /// </summary>
        private void DeleteScreenshots()
        {
            for (int index = 2; index < 5; index++)
            {
                string desktopName = "Desktop" + index.ToString();
                string path = ".\\" + desktopName;

                // If file exists and desktop do not exists, delete the file
                if (File.Exists(path) && !Desktops.DesktopExists(desktopName))
                {
                    File.Delete(path);
                }
            }// for
        }//


        /// <summary>
        /// Initialize current desktop name and delete old screenshots.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Form1_Load(object sender, EventArgs e)
        {
            // On first load start explorer
            if (Program.Start == "start")
            {
                Process.Start("explorer.exe");                                       // Start explorer
                Thread.Sleep(500);                                                         // Wait explorer to initialize

                // Reposition window on taskbar   
                this.Opacity = 0;
                this.WindowState = FormWindowState.Normal;
                this.WindowState = FormWindowState.Minimized;
                Thread.Sleep(300);
                this.Opacity = 100;
                this.Refresh();
            }

            // Initialize
            currentDesktop = Desktops.DesktopName(Desktops.DesktopOpenInput());
            DeleteScreenshots();
        }

        /// <summary>
        /// When form is activated load saved screenshots and initialize current PictureBox with current desktop image.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Form1_Activated(object sender, EventArgs e)
        {
            // Refresh/load screenshots
            LoadScreenshots();
            LoadScreenshot();

            // Set form caption
            string caption = currentDesktop;
            if (caption == "Default") { caption = "Desktop1"; }
            this.Text = "VirtualDesktop IGProgram - " + caption;
        }

        /// <summary>
        /// Minimize form when deactivated
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Form1_Deactivate(object sender, EventArgs e)
        {
            this.WindowState = FormWindowState.Minimized;
        }

        /// <summary>
        /// On PictureBox click minimize the form and activate selected desktop
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void pictureBox1_Click(object sender, EventArgs e)
        {
            this.WindowState = FormWindowState.Minimized;
            DesktopInitialize("Default");
        }

        /// <summary>
        /// On PictureBox click minimize the form and activate selected desktop
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void pictureBox2_Click(object sender, EventArgs e)
        {
            this.WindowState = FormWindowState.Minimized;
            DesktopInitialize("Desktop2");
        }

        /// <summary>
        /// On PictureBox click minimize the form and activate selected desktop
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void pictureBox3_Click(object sender, EventArgs e)
        {
            this.WindowState = FormWindowState.Minimized;
            DesktopInitialize("Desktop3");
        }

        /// <summary>
        /// On PictureBox click minimize the form and activate selected desktop
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void pictureBox4_Click(object sender, EventArgs e)
        {
            this.WindowState = FormWindowState.Minimized;
            DesktopInitialize("Desktop4");
        }

    }
}


