﻿// <copyright file="Screenshot.cs" company="IGProgram">
//      Copyright © Ivica Gjorgjievski 2010 All rights reserved.
//      http://www.igprogram.webs.com
//      igprogram@hotmail.com
// </copyright>

using System;
using System.Collections.Generic;
using System.Text;

using System.IO;
using System.Drawing;
using System.Drawing.Imaging;
using System.Windows.Forms;
using System.Threading;

namespace IGProgram.VirtualDesktop
{
    /// <summary>
    /// Capture screenshot to image and save it to file.
    /// </summary>
    class Screenshot
    {
        /// <summary>
        /// Save screenshot to file.
        /// </summary>
        /// <param name="filename">Name of the file</param>
        /// <param name="format">Format of the image</param>
        /// <param name="control">Control instance (any), necessary to get the current screen in multiple monitor system.</param>
        public static void SaveScreen(string filename, ImageFormat format, Control control)
        {
            // Delete the file if exists
            File.Delete(filename);
            
            // Crate and save screenshot
            using (Bitmap screenShot = CaptureScreen(control))
            {
                screenShot.Save(filename, format);
            }

        }// SaveScreen


        /// <summary>
        /// Saves screen shot to bitmap image.
        /// </summary>
        /// <param name="control">Control instance (any), necessary to get the current screen in multiple monitor system.</param>
        /// <returns>Screenshot in bitmap.</returns>
        public static Bitmap CaptureScreen(Control control)
        {
            // Get bounds of the current screen
            Rectangle bounds = Screen.FromControl(control).Bounds; 
          
            // Create bitmap
            Bitmap bitmap = new Bitmap(bounds.Width, bounds.Height);

            // Copy screen to bitmap
            using (Graphics graphics = Graphics.FromImage(bitmap))
            {
                graphics.CopyFromScreen(Point.Empty, Point.Empty, bounds.Size);
            }

            return bitmap;

        }// CaptureScreen


    }
}
